package com.tuigai.tuigai_tongcheng_api.utils;


import com.alibaba.fastjson.JSONObject;
import okhttp3.*;
import org.apache.commons.lang3.StringUtils;

import java.io.IOException;
import java.util.Map;
import java.util.concurrent.TimeUnit;

public class OkHttpUtil {

    private static OkHttpClient client = null;

    static {
        client = new OkHttpClient.Builder()
                .connectTimeout(60 * 1000, TimeUnit.MILLISECONDS)
                .readTimeout(60 * 1000, TimeUnit.MILLISECONDS)
                .writeTimeout(60 * 1000, TimeUnit.MILLISECONDS)
                .build();
    }

    /**
     * 发送HTTP GET请求
     *
     * @param uri
     * @return
     */
    public static String doGetRequest(String uri) throws IOException {
        Request getRequest = new Request.Builder()
                .url(uri)
                .get()
                .build();
        Call getCall = client.newCall(getRequest);
        Response getResponse = getCall.execute();
        return getResponse.body().string();
    }

    /**
     * 发送HTTP POST请求
     *
     * @param uri
     * @param body
     * @return
     * @throws IOException
     */
    public static String doPostRequest(String uri, String body) throws IOException {
        Request requst = new Request.Builder()
                .url(uri)
                .post(RequestBody.create(MediaType.parse("application/json;charset=utf-8"), body))
                .build();
        OkHttpClient build = new OkHttpClient.Builder().build();
        Call getCall = build.newCall(requst);
        Response getResponse = getCall.execute();
        return getResponse.body().string();
    }

    public static String doPostRequestFZ(String uri, String body) throws IOException {
        Request requst = new Request.Builder()
                .url(uri)
                .post(RequestBody.create(MediaType.parse("application/json;charset=utf-8"), body))
                .build();
        Call getCall = client.newCall(requst);
        Response getResponse = getCall.execute();
        return getResponse.body().string();
    }

    public static String doPostRequestWithHeader(String uri, String body, Map<String, String> headers) throws IOException {
        Request.Builder builder = new Request.Builder();
        headers.forEach((key, value) -> builder.addHeader(key, value));
        Request request = builder
                .url(uri)
                .post(RequestBody.create(MediaType.parse("application/json;charset=utf-8"), body))
                .build();
        Call getCall = client.newCall(request);
        Response getResponse = getCall.execute();
        assert getResponse.body() != null;
        return getResponse.body().string();
    }

    private static MultipartBody.Builder mapProperty(JSONObject jsonObject) {
        MultipartBody.Builder builder = new MultipartBody.Builder();
        for (String key : jsonObject.keySet()) {
            builder.addFormDataPart(key, StringUtils.isBlank(jsonObject.getString(key)) ? "" : jsonObject.getString(key));
        }

        return builder;
    }

    /**
     * 表单提交
     *
     * @param uri        请求路径
     * @param jsonObject 数据对象
     * @return
     * @throws IOException
     */
    public static String doPostRequestForm(String uri, JSONObject jsonObject) throws IOException {


        MultipartBody requestBody = mapProperty(jsonObject)
                .setType(MultipartBody.FORM) // 设置传参为form-data格式
                .build();

        // 构建request请求体，有需要传请求头自己加
        Request request = new Request.Builder()
                .url(uri)
                .header("Content-Type", "application/x-www-form-urlencoded;charset=utf8")
                .post(requestBody)
                .build();

//        Request requst = new Request.Builder()
//                .url(uri)
//                .post(RequestBody.create(MediaType.parse("application/x-www-form-urlencoded"),body))
//                .build();
        Call getCall = client.newCall(request);
        Response getResponse = getCall.execute();
        return getResponse.body().string();
    }







}
