package com.tuigai.tuigai_tongcheng_api.utils;

import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

/**
 * Spring工具类
 */
@Component
public class SpringContextUtil implements ApplicationContextAware {
    private static ApplicationContext applicationContext;

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        SpringContextUtil.applicationContext = applicationContext;
    }

    @SuppressWarnings("unchecked")
    public static <T> T getBean(String name) {
        return (T) SpringContextUtil.applicationContext.getBean(name);
    }

    public static <T> T getBean(Class<T> clazz) {
        return applicationContext.getBean(clazz);
    }

    public static ApplicationContext getApplicationContext() {
        return applicationContext;
    }

    /**
     * 是否为开发环境
     *
     * @return boolean
     */
    public static boolean isDev() {
        return "dev".equals(applicationContext.getEnvironment().getActiveProfiles()[0]);
    }

    public static String getEnv() {
        return applicationContext.getEnvironment().getActiveProfiles()[0];
    }

    /**
     * 是否为测试环境
     *
     * @return boolean
     */
    public static boolean isTest() {
        return "test".equals(applicationContext.getEnvironment().getActiveProfiles()[0]);
    }

    /**
     * 是否为生产环境
     *
     * @return boolean
     */
    public static boolean isProd() {
        return "release".equals(applicationContext.getEnvironment().getActiveProfiles()[0]);
    }
}
