package com.tuigai.tuigai_tongcheng_api.utils;

import java.io.*;
import java.math.BigDecimal;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.text.DecimalFormat;
import java.util.*;
import java.util.zip.GZIPInputStream;

/**
 * Created by longtc on 16/7/1.
 */
public final class Utils {

    public static final String S = "0123456789abcdefghijklmnopqrstuvwxyz";

    public static boolean isEmpty(String str) {
        return str == null || str.isEmpty();
    }

    public static boolean isEmpty(Collection c) {
        return c == null || c.isEmpty();
    }

    public static boolean isEmpty(Map map) {
        return map == null || map.isEmpty();
    }

    public static  boolean isEmpty(Object o){
        return  o == null || o.toString().equals("");
    }
    public static <T> boolean isEmpty(T[] t) {
        return t == null || t.length == 0;
    }

    //字符串生成md5串
    public static String stringMD5(String input) {
        try {
            MessageDigest messageDigest = MessageDigest.getInstance("MD5");
            byte[] inputByteArray = input.getBytes();
            messageDigest.update(inputByteArray);
            byte[] resultByteArray = messageDigest.digest();
            return bytesToHexString(resultByteArray);
        } catch (NoSuchAlgorithmException e) {
            return null;
        }
    }

    //bytes转成16进制字符串
    public static String bytesToHexString(byte[] bArray) {

        if (bArray == null) {
            return "";
        }

        final StringBuilder sb = new StringBuilder(bArray.length);
        for (int i = 0; i < bArray.length; i++) {
            String sTemp = Integer.toHexString(0xFF & bArray[i]);
            if (sTemp.length() < 2) {
                sb.append(0);
            }
            sb.append(sTemp.toLowerCase());
        }
        return sb.toString();
    }

    public static String randomString(int size) {

        final StringBuilder sb = new StringBuilder();
        final int bound = S.length();
        final Random r = new Random();

        for (int i = 0; i < size; i++) {
            int index = r.nextInt(bound);
            sb.append(S.charAt(index));
        }

        return sb.toString();
    }

    public static int random(int size) {
        final Random r = new Random();
        return r.nextInt(size);
    }
    public static int randomInt(int min,int max){
        Random random = new Random();
        return  random.nextInt(max)%(max-min+1) + min;
    }

    public static void sleep(long time) {
        try {
            Thread.sleep(time);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
    }

    public static boolean floatIsNull(float f){

        return f>-0.000001&&f<0.000001;
    }


    /**
     * gZip解压方法
     * */
    public static byte[] unGZip(byte[] data, String s) {
        byte[] b = null;
        try {
            ByteArrayInputStream bis = new ByteArrayInputStream(data);
            GZIPInputStream gzip = new GZIPInputStream(bis);
            byte[] buf = new byte[1024];
            int num = -1;
            ByteArrayOutputStream baos = new ByteArrayOutputStream();
            while ((num = gzip.read(buf, 0, buf.length)) != -1) {
                baos.write(buf, 0, num);
            }
            b = baos.toByteArray();
            baos.flush();
            baos.close();
            gzip.close();
            bis.close();
        } catch (Exception ex) {
            ex.printStackTrace();
        }
        return b;
    }

    /**
     * 解压并且Base64解码
     * @param responseContent
     * @return
     */
    public static String ungzipandunBase64(String responseContent) {
            return new String(unGZip(Base64.getDecoder().decode(responseContent), "utf-8"));


        }

    public static String join(String addstr, List<Integer> ids)  {

        StringBuilder sb = new StringBuilder();
        for (int a : ids) {
            if( a >0){
                sb.append(a).append(addstr);
            }
        }

        return  subDouhao(sb.toString());
    }

    public static  String subDouhao(String sb){
        if(null == sb || sb.length() < 1) return sb;
        String lastString = sb.substring(sb.length()-1);
        if(lastString.equals(",")){
            return  sb.substring(0, sb.length()-1);
        }else {
            return sb;
        }
    }

    public static int floatToInt(float f){
        int i = 0;
        if(f>0) //正数
        {
            i = (int)(f*10 + 5)/10;
        }
        else if(f<0) //负数
        {
            i =  (int)(f*10 - 5)/10;
        }
        else {
            i = 0;
        }
        return i;
    }



    public  static float StringToFloat(String fStr){
        try
        {
            if(Utils.isEmpty(fStr)){
                return 0f;
            }

            return Float.valueOf(fStr.trim()).floatValue();

        }
        catch (NumberFormatException nfe)
        {
            System.out.println("NumberFormatException: " + nfe.getMessage());
            System.out.println("字符串转换为float失败: " + fStr);
        }

        return 0f;
    }


    /**
     * 计算出单个人的价格
     * 后期需要修改为支持返回float
     * @param allprice
     * @param personCount
     * @return
     */
  public static int getSinglePrice(Float allprice,int personCount){
        if(Utils.isEmpty(personCount) || Utils.floatIsNull(allprice)) return 0;
        float singlePrice = allprice / personCount;
        return Utils.floatToInt(singlePrice);
  }



    public static boolean isNumeric(String str) {
        String bigStr;
        try {
            bigStr = new BigDecimal(str).toString();
        } catch (Exception e) {
            return false;//异常 说明包含非数字。
        }
        return true;
    }



    public static  <T> T deepClone(T instance) {
        ObjectOutputStream out = null;
        ObjectInputStream in = null;
        try {
            ByteArrayOutputStream byteOut = new ByteArrayOutputStream();
            out = new ObjectOutputStream(byteOut);
            out.writeObject(instance);
            in = new ObjectInputStream(new ByteArrayInputStream(byteOut.toByteArray()));
            return (T) in.readObject();
        } catch (Exception ex) {
            System.out.println("拷贝失败");
        } finally {
            try {
                if (in != null) {
                    in.close();
                }
                if (out != null) {
                    out.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
                System.out.println("拷贝异常");
            }
        }
        return null;
    }


    /**
     * 格式化float 默认返回。00格式
     * @param money
     * @param pattern
     * @return
     */
    public static String formatFloatToString(float money,String pattern){
        if(Utils.isEmpty(pattern)){
            pattern = ".00";
        }
        DecimalFormat decimalFormat=new DecimalFormat(pattern);//构造方法的字符格式这里如果小数不足2位,会以0补足.
        return decimalFormat.format(money);//format 返回的是字符串
    }

    public static String formatFloatToStringPercent(float money){
        DecimalFormat decimalFormat=new DecimalFormat("#.##%");//构造方法的字符格式这里如果小数不足2位,会以0补足.
        return decimalFormat.format(money);//format 返回的是字符串
    }



}
